
/*
 * qfits example: querying FITS headers.
 *
 * In this example, a FITS header is loaded and examined
 * using the qfits_header object.
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "qfits.h"

int main(int argc, char * argv[])
{
    /*
     * Declare a qfits_header object as a pointer.
     */
	qfits_header	*	qh ;

    /* The following are for header browsing only */
	int     i ;
	char	key[FITS_LINESZ+1] ;
	char	val[FITS_LINESZ+1] ;
	char	com[FITS_LINESZ+1] ;
	char	lin[FITS_LINESZ+1] ;

    /* Check command-line arguments. */
	if (argc<2) {
		printf("use: %s <filename>\n", argv[0]);
		return 1 ;
	}

    /* Check this is indeed a FITS file */
    if (is_fits_file(argv[1])!=1) {
        printf("%s is not a FITS file\n", argv[1]);
        return -1 ;
    }

	/*
	 * Load FITS header into qfits_header object.
	 * This only reads the main header. To read an extension
	 * header, you could use:
	 *
	 * qh = qfits_header_readext(argv[1], xtnum);
     * Notice that the following will also read the main header:
     * qh = qfits_header_readext(argv[1], 0) ;
	 *
	 */
	qh = qfits_header_read(argv[1]);
	if (qh==NULL) {
        /*
         * Something went wrong: bailout
         */
		return -1 ;
	}

	/*
	 * The loaded header can be dumped to a file using
	 * qfits_header_dump(), like in:
	 * qfits_header_dump(qh, stdout);
	 */

	/* Display all keywords found in header, and their type */
	for (i=0 ; i<qh->n ; i++) {
		/*
		 * Get for each card:
		 * - The keyword name
		 * - The keyword value
		 * - Any associated comment
		 * - The whole initial line as a pointer to 80 chars.
		 */
		qfits_header_getitem(qh, i, key, val, com, lin);

		/*
         * Display key name and value for cards that are not
         * HISTORY or COMMENT.
         */
        if (strcmp(key, "HISTORY") && strcmp(key, "COMMENT")) {

            printf("key(%s) value(%s) ", key, val);
            
            /*
             * Display the value type. See also the following functions:
             * qfits_is_boolean()
             * qfits_is_int()
             * qfits_is_float()
             * qfits_is_complex()
             * qfits_is_string()
             */
            switch (qfits_get_type(val)) {
                case QFITS_BOOLEAN:
                printf("type: boolean\n");
                break ;
        
                case QFITS_INT:
                printf("type: int\n");
                break ;

                case QFITS_FLOAT:
                printf("type: float\n");
                break ;

                case QFITS_COMPLEX:
                printf("type: complex\n");
                break ;

                case QFITS_STRING:
                printf("type: string\n");
                break ;

                default:
                printf("type: unknown\n");
                break ;
            }
            printf("comment(%s)\n", com);
        }
    }

    /* Free header and quit */
	qfits_header_destroy(qh);
	return 0 ;
}

